#
# spec file for package courier-authlib
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           courier-authlib
Version:        0.72.3
Release:        1.5
Summary:        Courier authentication library
License:        SUSE-GPL-3.0-with-openssl-exception
Group:          Productivity/Networking/Email/Servers
URL:            https://www.courier-mta.org/imap/
Source0:        https://downloads.sourceforge.net/courier/%{name}-%{version}.tar.bz2
Source1:        https://downloads.sourceforge.net/courier/%{name}-%{version}.tar.bz2.sig
# Keyring downloaded from https://www.courier-mta.org/KEYS.bin#/%%{name}.keyring
Source2:        %{name}.keyring
Source3:        courier-authdaemon-rpmlintrc
Source12:       courier-authdaemon.service
Source13:       courier-authlib.tmpfile
Patch0:         %{name}-authdaemonrc.patch
BuildRequires:  courier-unicode-devel >= 2.1
BuildRequires:  expect
BuildRequires:  gcc-c++
BuildRequires:  gdbm-devel
BuildRequires:  libtool
BuildRequires:  mysql-devel
BuildRequires:  openldap2-devel
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
BuildRequires:  postgresql-devel >= 9.1
BuildRequires:  pkgconfig(libidn2) >= 2.0.5
BuildRequires:  pkgconfig(systemd)
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150200
BuildRequires:  postgresql-server-devel
%endif
BuildRequires:  procps
BuildRequires:  sqlite3-devel
Requires(pre):  group(mail)
%{?systemd_requires}

%description
The Courier authentication library provides authentication services for
other Courier applications.

%package devel
Summary:        Development libraries for the Courier authentication library
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}
Requires:       %{name}-ldap = %{version}
Requires:       %{name}-mysql = %{version}
Requires:       %{name}-pgsql = %{version}
Requires:       %{name}-pipe = %{version}
Requires:       %{name}-sqlite = %{version}
Requires:       %{name}-userdb = %{version}

%description devel
This package contains the development libraries and files needed to
compile Courier packages that use this authentication library.	Install
this package in order to build the rest of the Courier packages.  After
they are built and installed this package can be removed.  Files in
this package are not needed at runtime.

%package userdb
Summary:        Userdb support for the Courier authentication library
Group:          Productivity/Networking/Email/Servers

%description userdb
This package installs the userdb support for the Courier authentication
library.  Userdb is a simple way to manage virtual mail accounts using
a GDBM-based database file.

%package ldap
Summary:        LDAP support for the Courier authentication library
Group:          Productivity/Networking/Email/Servers

%description ldap
This package installs LDAP support for the Courier authentication
library. Install this package in order to be able to authenticate using
LDAP.

%package mysql
Summary:        MySQL support for the Courier authentication library
Group:          Productivity/Networking/Email/Servers

%description mysql
This package installs MySQL support for the Courier authentication
library. Install this package in order to be able to authenticate using
MySQL.

%package pgsql
Summary:        PostgreSQL support for the Courier authentication library
Group:          Productivity/Networking/Email/Servers

%description pgsql
This package installs PostgreSQL support for the Courier authentication
library. Install this package in order to be able to authenticate using
PostgreSQL.

%package pipe
Summary:        Pipe support for the Courier authentication library
Group:          Productivity/Networking/Email/Servers

%description pipe
This package installs Pipe support for the Courier authentication
library. Install this package in order to be able to authenticate using
Pipe.

%package sqlite
Summary:        SQLite support for the Courier authentication library
Group:          Productivity/Networking/Email/Servers

%description sqlite
This package installs SQLite support for the Courier authentication
library. Install this package in order to be able to authenticate using
SQLite.

%prep
%autosetup

%build
export CFLAGS="%{optflags} -DLDAP_DEPRECATED=1"
%configure \
	--libexecdir=%{_prefix}/lib \
	--datadir=%{_datadir}/courier-imap \
	--sharedstatedir=%{_sharedstatedir}/%{name} \
	--with-piddir=%{_rundir} \
	--disable-root-check \
	--enable-unicode \
	--with-authdaemonvar=%{_rundir}/%{name} \
	--host=%{_host} --build=%{_build} --target=%{_target_platform}
%make_build

%install
%make_install
mv %{buildroot}%{_libdir}/%{name}/lib*.so* %{buildroot}%{_libdir}
rm -f %{buildroot}/%{_libdir}/%{name}/*.{a,la}
install -m 755 sysconftool %{buildroot}/%{_prefix}/lib/%{name}
install -D -m 0644 %{SOURCE12} %{buildroot}/%{_unitdir}/courier-authdaemon.service
# systemd need to create a tmp dir: /run/courier-authlib
install -d -m755 %{buildroot}%{_tmpfilesdir}
install -D -m 0644 %{SOURCE13} %{buildroot}%{_tmpfilesdir}/%{name}.conf
ln -fs service %{buildroot}/%{_sbindir}/rccourier-authdaemon

%pre
%service_add_pre courier-authdaemon.service

%preun
%if 0%{?suse_version}
%stop_on_removal courier-authdaemon
%endif
%service_del_preun courier-authdaemon.service
if [ "$1" = "0" ]; then
	for i in socket pid pid.lock; do
		rm -f %{_rundir}/%{name}/$i
	done
fi

%post
/sbin/ldconfig
%{_prefix}/lib/%{name}/sysconftool %{_sysconfdir}/authlib/*.dist >/dev/null
%service_add_post courier-authdaemon.service
%tmpfiles_create %{_prefix}/lib/tmpfiles.d/%{name}.conf

%postun
/sbin/ldconfig
%service_del_postun courier-authdaemon.service

%post userdb -p /sbin/ldconfig
%postun userdb -p /sbin/ldconfig
%post ldap -p /sbin/ldconfig
%postun ldap -p /sbin/ldconfig
%post mysql -p /sbin/ldconfig
%postun mysql -p /sbin/ldconfig
%post pgsql -p /sbin/ldconfig
%postun pgsql -p /sbin/ldconfig
%post pipe -p /sbin/ldconfig
%postun pipe -p /sbin/ldconfig
%post sqlite -p /sbin/ldconfig
%postun sqlite -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc README README*html
%license COPYING*
%doc NEWS AUTHORS ChangeLog authldap.schema
%dir %{_sysconfdir}/authlib
%config %{_sysconfdir}/authlib/*
%{_sbindir}/authdaemond
%{_sbindir}/authenumerate
%{_sbindir}/authpasswd
%{_sbindir}/authtest
%{_sbindir}/courierlogger
%{_sbindir}/rccourier-authdaemon
%dir %{_prefix}/lib/%{name}
%{_prefix}/lib/%{name}/sysconftool
%{_prefix}/lib/%{name}/authdaemond
%{_prefix}/lib/%{name}/authsystem.passwd
%{_prefix}/lib/%{name}/makedatprog
%{_libdir}/libauthcustom.so.*
%{_libdir}/libauthpam.so.*
%{_libdir}/libcourierauth.so.*
%{_libdir}/libcourierauthcommon.so.*
%{_libdir}/libcourierauthsasl.so.*
%{_libdir}/libcourierauthsaslclient.so.*
%{_mandir}/man1/*
%{_unitdir}/courier-authdaemon.service
%{_prefix}/lib/tmpfiles.d/%{name}.conf
%ghost %dir %{_rundir}/%{name}

%files devel
%defattr(-,root,root,-)
%doc authlib.html auth_*.html
%{_bindir}/courierauthconfig
%{_includedir}/*
%{_libdir}/*.so
%{_mandir}/man3/*

%files userdb
%defattr(-,root,root,-)
%{_sbindir}/makeuserdb
%{_sbindir}/pw2userdb
%{_sbindir}/userdb
%{_sbindir}/userdbpw
%{_libdir}/libauthuserdb.so.*
%{_mandir}/man8/*userdb*

%files ldap
%defattr(-,root,root,-)
%doc README.ldap authldap.schema
%{_libdir}/libauthldap.so.*

%files mysql
%defattr(-,root,root,-)
%{_libdir}/libauthmysql.so.*

%files pgsql
%defattr(-,root,root,-)
%{_libdir}/libauthpgsql.so.*

%files pipe
%defattr(-,root,root,-)
%{_libdir}/libauthpipe.so.*

%files sqlite
%defattr(-,root,root,-)
%{_libdir}/libauthsqlite.so.*

%changelog
* Thu Aug  8 2024 Arjen de Korte <suse+build@de-korte.org>
- update to 0.72.3
  * courier-debuild: implement DEBGCC=default, to help with pbuilder.
  * courier-authlib.spec.in: Update dependencies to build against
    mariadb-devel instead of mysql-devel.
  * courier-authlib.spec.in: Packaging fixes.
- update to 0.72.2
  * courier-authlib.spec.in: Fedora 40 fixes.
* Wed Feb 21 2024 Arjen de Korte <suse+build@de-korte.org>
- Change to %%autosetup as RPM 4.20 will no longer support %%patchN
* Wed Jan 31 2024 Arjen de Korte <suse+build@de-korte.org>
- update to 0.72.1:
  * Assorted fixes for potential issues with proper C library usage.
  * Updated rpm and deb packages that guard against updates to newer
    versions with different compilation options.
- update courier-authlib.keyring with new signing key
* Sun Dec  4 2022 Arjen de Korte <suse+build@de-korte.org>
- update to 0.72.0:
  * Switch to libidn2.
  * Debian/Ubuntu: update lintian overrides
- update to 0.71.6:
  * Adjust deb packaging. Check /etc/lsb-release and include the
    distribution release in the deb package version, to faciliate
    updating to the same version of the package in an updated release.
  * Fix build dependencies.
  * Remove obsolete setting from authpgsqlrc, update connection string
    template.
* Sat Aug 20 2022 Arjen de Korte <suse+build@de-korte.org>
- update to 0.71.5:
  * gcc 12 and autotools update.
  * Add scripts to create installable .deb packages, update
    documentation.
* Tue Mar  8 2022 Arjen de Korte <suse+build@de-korte.org>
- update to 0.71.4:
  * Fix a theoretical memory corruption during authentication if the
    process runs out of memory. The server does not do much memory
    allocation prior to authentication, this is mostly academic.
* Mon Aug 30 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s). Modified:
  * courier-authdaemon.service
* Tue Apr 13 2021 Arjen de Korte <suse+build@de-korte.org>
- update to 0.71.3
  * courier-authlib: Report failed LDAP authenticated bind correctly.
* Sun Apr  4 2021 Arjen de Korte <suse+build@de-korte.org>
- Change ownership of socket directory from root:root to root:mail
  to allow postfix SASL auth to work
  %% courier-authlib.tmpfile
* Sat Mar 20 2021 Arjen de Korte <suse+build@de-korte.org>
- update to 0.71.2
  * No relevant changes for (open)SUSE build
- update source download URL
- fix unsafe permissions for socket directory (boo#1183724)
  %% courier-authlib.tmpfile
* Wed Feb 10 2021 Arjen de Korte <suse+build@de-korte.org>
- update to 0.71.1
  * Clean up header files, do not install autoconf-generated
    courier_auth_config.h
* Fri Jun 19 2020 Arjen de Korte <suse+build@de-korte.org>
- update to 0.71.0
  * userdb: Make userdb script accept UTF-8 domain names. Document
    it in the man page.
  * Configure and installed versioned shared libraries, both shared
    and the authentication modules.
  * Update INSTALL. Remove obsolete pre-courier authlib migration
    script and documentation. It's been long enough.
  * Add _meta API functions with an extra auth_meta parameter,
    keep the original functions as wrappers that provide a stub meta
    parameter. Use this to pass arbitrary variables to authdaemon.
  * authdaemond.c: retrieve the TCPREMOTEIP variable if it's provided.
  * authpam.c: TCPREMOTEIP, if set, sets PAM_RHOST.
  * Makefile.am (commonldflags): Link all libraries with the
  - -enable-new-dtags flag.
- rpmlint
  o addFilter shared-lib-calls-exit
* Thu May 28 2020 Arjen de Korte <suse+build@de-korte.org>
- update to 0.70.0
  * authsasl.c (auth_sasl_ex): For EXTERNAL, base64-decode the
    initial authorization string, since if none is provided the
    callback's reply is base64-decoded.
* Tue Mar 17 2020 Max Lin <mlin@suse.com>
- BuildRequires postgresql-server-devel on Leap >= 15.2
* Tue Nov 12 2019 Arjen de Korte <suse+build@de-korte.org>
- update to 0.69.1
  * authldaplib.cpp (ldapopen): Make sure that we rebind if we reconnect,
    if so configured.
  * authldaplib.cpp: Fix handling of LDAP configurations that use the
    same LDAP attribute for two or more variables.
- update to 0.69.0
  * authdaemond.c: set FD_CLOEXEC on socket file descriptors, to avoid
    leaks to child processes.
  * authldaplib.cpp: improve automatic reconnection logic to the LDAP
    server.
  * authsaslclient.h (SASL_LIST): Reorder SASL methods, strongest
    first.
- add courier-authlib.keyring for source verification
- remove obsolete SysV courier-authdaemon.init
- cleanup spec
* Tue Jun 11 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut the build queues by allowing usage of systemd-mini
* Tue Apr  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add the missing dependencies for Tumbleweed.
* Mon Dec  4 2017 suse+build@de-korte.org
- update to 0.68.0
  * authldaplib.cpp: Rewrite authldap in modern C++. Autodetect
    and automatically reload authldaprc when it is changed. No server
    restart is required.
  * authldaplib.cpp (operator): Fix compilation warning.
  * checkpassword.c (do_authcheckpassword): Check for a null return
    value from crypt().
  * authsqlite, authmysql, authpgsql: Rewrite these modules in
    modern C++. Autodetect and automatically reload the configuration
    file when it's changed, no server restart is needed.
  * userdb/userdbpw.c (main): Use bcrypt_gensalt() on OpenBSD
  * courierauth.h: Move declarations from cramlib.h into courierauth.h,
    exporting them as part of the public API.
  * configure.ac: Rebuild against updated courier-unicode API.
* Tue Apr 11 2017 jengelh@inai.de
- Drop redundant %%clean section. Dissolve %%__-type macros.
* Fri Mar 17 2017 kukuk@suse.com
- Don't install init script if we use systemd
* Sat Feb 18 2017 kukuk@suse.com
- Don't call insserv if we use systemd
* Mon May 16 2016 chris@computersalat.de
- udpate to 0.66.4
  * authgetconfig.c (authgetconfig): avoid invalid memory read.
* Wed Aug  5 2015 chris@computersalat.de
- update to 0.66.3
  * authdaemon.c: auth_callback_default_autocreate, default callback
  used by clients that autocreates a home directory, if one does not
  exist already.
- update to 0.66.2
  * Update to courier-unicode 1.2.
  * liblock, couriertls: fix compilation for OpenBSD -- based on a
  patch from Giovanni Bechis <giovanni@paclan.it>.
  * checkpassword.c (safe_strcmp): Fix bug introduced in 2014-04-27.
  * courier.spec.in: Update to use systemd macros.
  * Check for NULL return value from crypt().
  * Factored out the unicode library into a separate package.
- add BuildRequires courier-unicode-devel
- fix deps (SLE_11_SP4) to build againts pgsql >= 9.1
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashism in preun script
* Thu Jul 31 2014 dimstar@opensuse.org
- Rename rpmlintrc to %%{name}-rpmlintrc.
  Follow the packaging guidelines.
* Tue Mar 18 2014 chris@computersalat.de
- fix missing LOGGEROPTS in authdaemonrc
  * added patch courier-authlib-authdaemonrc.patch
* Mon Mar 17 2014 chris@computersalat.de
- fix for bnc#751125
  * maildrop can not access courier-authlib socket
* Sat Mar 15 2014 chris@computersalat.de
- update to 0.66.1
  * Makefile.am: run sysconftool on authsqliterc, in install-configure.
    Remove .la files for authentication modules, keep then for actual
    API libraries. Install them in the -devel RPM package.
  * userdb/Makefile.am: Stub for the pw2userdb(8) man page.
  * courier-authlib.service.in: Added Install target.
- added systemd service file
- add own tmpfiles.d file
  * courier-authlib.tmpfile
- remove obsolete makedat patch
* Mon Nov 11 2013 chris@computersalat.de
- update to 0.66
  * sqlite fixes.
  * authldaplib.c (ldapopen): Added LDAP_INITBIND option.
  * Makefile.am: chmod $(pkglibexecdir) explicitly to 755
  * courier-authlib.spec.in: Typo.
- add Source sig file
- add makedat patch
  * fix wrong source path to install makedatprog
* Tue Jan 15 2013 chris@computersalat.de
- update to 0.65.0
  * New authsqlite authentication module.
  * Fixed: when using authpgsql, if the Postgres server goes down
    authpgsql will then start leaking memory.
  * Fixed error codes returned by several authentication modules that
    prevent certain combinations of authentication modules from being
    used together.
- fix deps
  * add missing pkg-config
- add module sqlite
* Mon Sep 24 2012 cfarrell@suse.com
- license update: SUSE-GPL-3.0-with-openssl-exception
  Contains an exception to permit linking with openssl
* Fri Sep 21 2012 chris@computersalat.de
- update to 0.64.0
  * authpam.c (callback_pam): Call pam_end() after an authentication
    attempt.
  * Makefile.am: Renamed authstaticlist.h to courierauthstaticlist.h, and
    added it to the list of header files that 'make install' puts into
    includedir.
  * Fix gcc 4.6 warnings
  * courier.spec.in: switch to systemd.
  * Fix autoconf warnings.
  * courier-authlib.spec: Make rmplint happy.
- 0.63.1
  * Remove the bundled libtdl library. Require the system-installed
    libltdl library.
  * authmysqllib.c (auth_mysql_setpass): Fix crash if DEFAULT_DOMAIN
    is not set in the config file.
- fix license (GPL-2.0+ -> GPL-3.0+)
* Wed Oct 26 2011 chris@computersalat.de
- fix init script
  * add ldap mysql to Should-Start/Stop
* Wed Sep 21 2011 chris@computersalat.de
- change --with-authdaemonvar to /var/run/{name}
- rework init script
  * create PID DIR
- some spec cleanup
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use _smp_mflags for parallel build
* Wed Feb 24 2010 chris@computersalat.de
- update to 0.63.0
  * authldapescape.c: Factor out LDAP string escape function.
  * authldap.schema: Various fixes
  * authldap.ldif (olcObjectClasses): Create LDIF format schema from
    authldap.schema
  * authoption.c (auth_getoptionenvint): For account options that
    are parsed to an int, an option value that begins with t, T, y, or Y
    is evaluated as 1, other alphabetic values as 0; so that 'true'
    or 'yes' get evaluated as 1.
* Sat Sep  5 2009 chris@computersalat.de
- update to new version 0.62.4
  * Various compilation fixes for gcc 4.4 and libtool 2.2
  o 0.62.3
  * courier-authlib.spec.in (MAKEFLAGS): Explicit path to ./configtmp
  * README_authlib.sgml: Fixed documentation of authpipe AUTH command.
  * authmigrate.in (rc): Add /etc/courier-imap
- removed define for authdaemonvar
- fixed DEBUG_LOGIN
  o added export DEBUG_LOGIN to init script
- rpmlint
  o addFilter incoherent-init-script-name courier-authdaemon
  o addFilter shlib-policy-missing-suffix
* Wed Sep  2 2009 chris@computersalat.de
- spec mods
  o added norootforbuild
  o define authdaemondir
  o post authmigrate, sysconftool
* Thu Aug 20 2009 chris@computersalat.de
- cleanup spec file
  o fixed header
  o removed all #---- lines
  o fixed devel Group
  o added configure macro
- rpmlint
  o added rpmlintrc
  o subpackages libauth[name] back to subpackage-[name]
    rpmlint warning can be ignored for libauth[names]
  o fixed non-conffile-in-etc
* Mon Apr 13 2009 chris@computersalat.de - 0.62.2
- update to new version 0.62.2
  o Makefile.am: Compatibility fix for bash 4
- 0.62.1
  o cryptpassword.c: Fix compiler warnings
  o checkpasswordsha1.c: Fix compiler warnings.
  o authldaplib.c (auth_ldap_enumerate): Fix typo.
- 0.62.0
  o authpgsqllib.c: Use PQescapeStringConn() instead of removing all
    apostrophes from query parameters. This fixes a potential SQL injection
    vulnerability if the Postgres database uses a non-Latin locale.
- 0.61.1
  o authsasllogin.c (authsasl_login): Fix memory leak.
  o authldaplib.c (read_env): Fix resource leak. authldap did not close
    the authldaprc configuration file after reading it on startup.
  o authldaplib.c (auth_ldap_do2): Fix used ptr after free(). When an
    email map feature is enabled, and the map failed, the resulting
    error message was formed from a buffer that was recently free()ed.
  o authpipe.c (auth_pipe): Fix memory leak. If the fork() system call
    failed (unlikely), a buffer wasn't getting released.
* Sat Nov 15 2008 chris@computersalat.de - 0.61.0  
- rpmlint
  o set devel Group
  o removed dot 'Summary ended with dot'
  o renamed subpackages[names] to libauth[names]
  o replaced macro run_ldconfig with /sbin/ldconfig
  o modified post: insserv authdaemon
    activate syslog if not running (build error)
* Fri Sep  5 2008 hvogel@suse.de
- update to version 0.61.0
  * Cleanup: always compile md5, sha* and hmac stuff, and remove all
  conditionally-compiled cruft. Move SASL list to an internal header.
  Add client-side support for AUTH EXTERNAL.
  * authsasl.c (auth_sasl_ex): auth_sasl_ex() supercedes auth_sasl(),
  invokes auth_sasl() for non-EXTERNAL SASL methods, implements EXTERNAL
  by going through the motions, then setting up a dummy authentication
  request.
  * authdaemon.c (auth_generic): Check for the dummy EXTERNAL
  authentication request, and handle it by invoking auth_getuserinfo(),
  rather than sending it down the pipe. This avoid having to implement
  a stub in every authentication module.
  * authmysqllib.c: Use mysql_set_character_set() instead of SET NAMES
  * authmysqllib.c: Fix domain-less queries.
  * Drop the unmaintained authvchkpw module.
  * authmysqllib.c: Cleanup. Use mysql_real_escape_string instead of
  crude filtering.
  * More portability fixes.
- add rpmlintrc (shlib-policy-name-error) for the moment
  to fix build
* Sat Aug 16 2008 chris@computersalat.de - 0.61.0  
- update to new version 0.61.0
- beautify spec file ;)
- fixed BuildRequires for suseversion >= 103
  o gdbm-devel
  o procps
- some rpmlint fixes
  o added PreReq coreutils
  o removed obsolete X-UnitedLinux from init script
    fixed service-names
* Mon Apr 14 2008 aj@suse.de
- Small changes to make rpmlint happier:
  * Rename keywords in init scripts
  * Prerequire /bin/rm
* Thu Jan 17 2008 mskibbe@suse.de
- update to version 0.60.2 which
  o Portability fix for checking the highest available file
    descriptor
  o Fix typos
  o Use OPEN_MAX, instead of hardcoded
* Thu Jun  7 2007 ro@suse.de
- remove explicit requires for mysql-shared (library is required
  anyway)
* Wed Apr 25 2007 mskibbe@suse.de
- update to version 0.59.3 which includes:
  o CRAM authentication in vchpw module
  o bug fixes
  o updated man pages
* Thu Mar 29 2007 rguenther@suse.de
- Add procps BuildRequires due to interesting configure checks
* Mon Mar 26 2007 rguenther@suse.de
- Add gdbm-devel BuildRequires
* Thu Feb 22 2007 mskibbe@suse.de
- update to version 0.59.1 which
  o fix some bugs
  o Make the spec a little prettier
  o Change distro-detection to use "rh" and "fc" for version
    detection, and add support for mandriva
  o Added the -f option to makeuserdb
  o Try to recover when the LDAP server closes the
    persistent socket, for inactivity
* Mon Sep 18 2006 mskibbe@suse.de
- fix Bug 204834 - missing rccourier-authdaemon symlink
* Tue Aug  1 2006 mskibbe@suse.de
- Add mysql, pipe, pgsql sub-packages
* Mon Mar 27 2006 kukuk@suse.de
- Add missing ldconfig calls
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Dec 14 2005 kukuk@suse.de
- Update to 0.58 (enable shadow aging support)
* Sun Sep 25 2005 kukuk@suse.de
- Compile with -DLDAP_DEPRECATED
* Fri Jul 29 2005 kukuk@suse.de
- Initial version
